# aeneas.cew

**aeneas.cew** is a Python C extension to synthesize text with eSpeak.

## API

See the [__init__.py](__init__.py) file.

## Compiling the Python C extension locally

```bash
$ python cew_setup.py build_ext --inplace
```

## Compiling the pure C driver program

```bash
$ bash 000_compile_driver.sh
```



